@@ -1,9 +1,10 @@
-from types import ModuleType
-from typing import Union
 from unittest import mock
 
+# noinspection PyProtectedMember
 from django.test.utils import TestContextDecorator
 
+
+# noinspection PyPep8Naming
 class override_defaults(TestContextDecorator):
     """
     A tool for convenient override default values in config files
@@ -15,24 +16,21 @@ class override_defaults(TestContextDecorator):
     """
     enable_exception = None
 
-    def __init__(self, settings_file: Union[ModuleType, str], **kwargs):
+    def __init__(self, app_name: str, **kwargs):
         """ Save initial parameters.
 
-        :param settings_file: the name or reference on setting file
-        :param kwargs: settings file attributes and values to override
+        :param app_name: the application name
+        :param kwargs: default attributes and values to override
         """
-        if isinstance(settings_file, str):
-            self.module = settings_file
-        else:
-            self.module = settings_file.__name__
+        self.app_name = app_name
         self.settings = kwargs
         self.patchers = []
         super().__init__()
 
     def enable(self):
         """ Create patchers, start save and start them. """
-        for settings, value in self.settings.items():
-            patcher = mock.patch(f'{self.module}.{settings}', value)
+        for setting, value in self.settings.items():
+            patcher = mock.patch(f'{self.app_name}.defaults.{setting}', value)
             self.patchers.append(patcher)
             patcher.start()
 
@@ -40,4 +38,3 @@ class override_defaults(TestContextDecorator):
         """ Stop patchers. """
         for patcher in self.patchers:
             patcher.stop()
-
